# Docs #

### Using curation inference APIs ###

```python
import ipc
```

Authenticate
```python
ipc.init("<polly_token>")
```

Assigning ontology tags to some text
```python
ipc.tag("This mouse has cancer. We took apart its lungs and found ACE2 upregulation")

# [Tag(name='lung', ontology_id='BTO:0000763', entity_type='tissue'),
#  Tag(name='Neoplasms', ontology_id='MESH:D009369', entity_type='disease'),
#  Tag(name='Mus musculus', ontology_id='NCBI:txid10090', entity_type='species'),
#  Tag(name='ACE2', ontology_id='HGNC:13557', entity_type='gene')]
```

`ipc.tag` is a wrapper around `ipc.run_ner`, `ipc.normalize` and does all pre-processing / post-processing needed


To normalize a mention
```python
ipc.normalize("lung cancer", "disease")

# {'ontology': 'MESH',
#  'ontology_id': 'D008175',
#  'name': 'Lung Neoplasms',
#  'entity_type': 'disease',
#  'score': 199.80618286132812,
#  'synonym': 'cancer, lung'}
```
Its best not to specify a threshold and just use the default value instead

```python
ipc.run_ner("Gene expression profiling on mice lungs and reveals ACE2 upregulation")

# [{'keyword': 'ACE2',
#   'entity_type': 'gene',
#   'span_begin': 52,
#   'span_end': 55,
#   'score': 0.9900580048561096},
#  {'keyword': 'mice',
#   'entity_type': 'species',
#   'span_begin': 29,
#   'span_end': 32,
#   'score': 0.9896053075790405},
#  {'keyword': 'lungs',
#   'entity_type': 'tissue',
#   'span_begin': 34,
#   'span_end': 39,
#   'score': 0.9958996176719666}]
```

To run abbreviation detection separately
```python
ipc.find_abbreviations("so what's the deal with hepatocellular carcinoma (HCC)??")
# {'HCC': 'hepatocellular carcinoma'}
```

```python
import pandas as pd

sample_metadata = pd.DataFrame({"sample_id": [1, 2, 3, 4], "disease": ["control1", "ctrl2", "healthy", "HCC"],})
   
#    sample_id   disease
# 0          1  control1
# 1          2     ctrl2
# 2          3   healthy
# 3          4       HCC

ipc.assign_control_pert_labels(sample_metadata, columns_to_exclude=["sample_id"])

#    sample_id   disease  is_control control_prob
# 0          1  control1        True         1.00
# 1          2     ctrl2        True         1.00
# 2          3   healthy        True         0.96
# 3          4       HCC       False         0.08
```
